Index: code/trunk/src/modules/objects/triggers/MultiTrigger.cc
===================================================================
--- code/trunk/src/modules/objects/triggers/MultiTrigger.cc	(revision 11020)
+++ code/trunk/src/modules/objects/triggers/MultiTrigger.cc	(revision 11071)
@@ -124,13 +124,13 @@
         // Let the MultiTrigger return the states that trigger and process the new states if there are any.
         std::queue<MultiTriggerState*>* queue  = this->letTrigger();
-        if(queue != NULL)
+        if(queue != nullptr)
         {
             while(queue->size() > 0)
             {
                 MultiTriggerState* state = queue->front();
-                // If the state is NULL. (This really shouldn't happen)
-                if(state == NULL)
+                // If the state is nullptr. (This really shouldn't happen)
+                if(state == nullptr)
                 {
-                    orxout(internal_error, context::triggers) << "In MultiTrigger '" << this->getName() << "' (&" << this << "), Error: State of new states queue was NULL. State ignored." << endl;
+                    orxout(internal_error, context::triggers) << "In MultiTrigger '" << this->getName() << "' (&" << this << "), Error: State of new states queue was nullptr. State ignored." << endl;
                     queue->pop();
                     continue;
@@ -227,5 +227,5 @@
                             {
                                 // If the MultiTrigger is set to broadcast and has no originator a boradcast is fired.
-                                if(this->getBroadcast() && state->originator == NULL)
+                                if(this->getBroadcast() && state->originator == nullptr)
                                     this->broadcast(bActive);
                                 // Else a normal event is fired.
@@ -240,11 +240,11 @@
                         {
                             // Print some debug output if the state has changed.
-                            if(state->originator != NULL)
+                            if(state->originator != nullptr)
                                 orxout(verbose, context::triggers) << "MultiTrigger '" << this->getName() << "' (&" << this << ") changed state. originator: " << state->originator->getIdentifier()->getName() << " (&" << state->originator << "), active: " << bActive << ", triggered: " << state->bTriggered << "." << endl;
                             else
-                                orxout(verbose, context::triggers) << "MultiTrigger '" << this->getName() << "' (&" << this << ") changed state. originator: NULL, active: " << bActive << ", triggered: " << state->bTriggered << "." << endl;
+                                orxout(verbose, context::triggers) << "MultiTrigger '" << this->getName() << "' (&" << this << ") changed state. originator: nullptr, active: " << bActive << ", triggered: " << state->bTriggered << "." << endl;
 
                             // If the MultiTrigger has a parent trigger, that is itself a MultiTrigger, it needs to call a method to notify him, that its activity has changed.
-                            if(this->parent_ != NULL && this->parent_->isMultiTrigger())
+                            if(this->parent_ != nullptr && this->parent_->isMultiTrigger())
                                 static_cast<MultiTrigger*>(this->parent_)->childActivityChanged(state->originator);
                         }
@@ -265,5 +265,5 @@
                 else
                 {
-                    this->stateQueue_.push_back(std::pair<float, MultiTriggerState*>(timeRemaining-dt, state));
+                    this->stateQueue_.emplace_back(timeRemaining-dt, state);
                     this->stateQueue_.pop_front();
                 }
@@ -299,5 +299,5 @@
 
         // If the target is not a valid class name display an error.
-        if (target == NULL)
+        if (target == nullptr)
         {
             orxout(internal_error, context::triggers) << "'" << targetStr << "' is not a valid class name to include in ClassTreeMask (in " << this->getName() << ", class " << this->getIdentifier()->getName() << ")" << endl;
@@ -327,5 +327,5 @@
 
         // If the target is not a valid class name display an error.
-        if (target == NULL)
+        if (target == nullptr)
         {
             orxout(internal_error, context::triggers) << "'" << targetStr << "' is not a valid class name to include in ClassTreeMask (in " << this->getName() << ", class " << this->getIdentifier()->getName() << ")" << endl;
@@ -346,5 +346,5 @@
     std::queue<MultiTriggerState*>* MultiTrigger::letTrigger(void)
     {
-        return NULL;
+        return nullptr;
     }
 
@@ -443,6 +443,6 @@
     void MultiTrigger::fire(bool status, BaseObject* originator)
     {
-        // If the originator is NULL, a normal event without MultiTriggerContainer is sent.
-        if(originator == NULL)
+        // If the originator is nullptr, a normal event without MultiTriggerContainer is sent.
+        if(originator == nullptr)
         {
             this->fireEvent(status);
@@ -479,5 +479,5 @@
     bool MultiTrigger::addState(MultiTriggerState* state)
     {
-        assert(state); // The state really shouldn't be NULL.
+        assert(state); // The state really shouldn't be nullptr.
 
         // If the originator is no target of this MultiTrigger.
@@ -489,5 +489,5 @@
 
         // Add it ot the state queue with the delay specified for the MultiTrigger.
-        this->stateQueue_.push_back(std::pair<float, MultiTriggerState*>(this->getDelay(), state));
+        this->stateQueue_.emplace_back(this->getDelay(), state);
 
         return true;
@@ -504,7 +504,6 @@
     bool MultiTrigger::checkAnd(BaseObject* triggerer)
     {
-        for(std::set<TriggerBase*>::iterator it = this->children_.begin(); it != this->children_.end(); ++it)
-        {
-            TriggerBase* trigger = *it;
+        for(TriggerBase* trigger : this->children_)
+        {
             if(trigger->isMultiTrigger())
             {
@@ -531,7 +530,6 @@
     bool MultiTrigger::checkOr(BaseObject* triggerer)
     {
-        for(std::set<TriggerBase*>::iterator it = this->children_.begin(); it != this->children_.end(); ++it)
-        {
-            TriggerBase* trigger = *it;
+        for(TriggerBase* trigger : this->children_)
+        {
             if(trigger->isMultiTrigger())
             {
@@ -559,7 +557,6 @@
     {
         bool triggered = false;
-        for(std::set<TriggerBase*>::iterator it = this->children_.begin(); it != this->children_.end(); ++it)
-        {
-            TriggerBase* trigger = *it;
+        for(TriggerBase* trigger : this->children_)
+        {
             if(triggered)
             {
